@@ -28,13 +28,18 @@ class Component(object):
         cls.data = json.load(loader.file('data/components/%s.json' % cls.__name__.lower()))
         cls.image = loader.image('data/' + cls.data['name'])
         ax, ay = cls.data['offset']
+
         # FIXME: this loading is really cludgey
         offset = v(ax, ay)
+
+        # Compute circles relative to top left (y-down)
         circles = []
-        circles.append((v(0, 0), cls.data['radius']))
+        circles.append((-offset, cls.data['radius']))
         for point in cls.data.get('points', []):
-            centre = v(point['offset']) + offset
-            circles.append((v(centre.x, -centre.y), point['radius']))
+            centre = v(point['offset'])
+            circles.append((v(centre.x, centre.y), point['radius']))
+
+        # Compute centre of gravity relative to top left (y-down)
         total_area = 0
         cs2 = []
         for c, r in circles:
@@ -45,26 +50,43 @@ class Component(object):
         density = cls.MASS / total_area
 
         cog = v(0, 0)
-        moi = 0
         for c, r, area in cs2:
             cog += c * (area / total_area) 
+
+        # Compute moment of inertia
+        moi = 0
+        for c, r, area in cs2:
             moi += pymunk.moment_for_circle(density * area, 0, r, c - cog)
-
-        cls.cog = cog
-        offset -= cog
-        cls.circles = [(c - cog, r) for c, r in circles]
-
-        cls.image.anchor_x = -int(offset.x + 0.5)
-        cls.image.anchor_y = cls.yfix * int(cls.image.height + offset.y + 0.5)
-        cls.insertion_point = -cog
         cls.moi = moi  # moment of inertia
 
+        # Now make all shapes relative to new COG (y up)
+        cls.circles = []
+        for c, r in circles:
+            c -= cog
+            pos = v(c.x, -c.y)
+            cls.circles.append((pos, r))
+
+        # And make anchor point the COG
+        cls.image.anchor_x = int(cog.x + 0.5)
+        cls.image.anchor_y = int(cls.image.height - cog.y + 0.5)
+
+        # And make insertion point the offset of the COG (y up)
+        ins = cog + offset
+        cls.insertion_point = v(ins.x, -ins.y)
+
     def __init__(self, squid, attachment_point):
         self.squid = squid
         self.attachment_point = attachment_point
         self.sprite = pyglet.sprite.Sprite(self.image, 0, 0)
+        self.body = None
+
+    def attach_at_slot(self, slot):
+        self.slot = slot
+        self.attachment_point = slot.pos
 
     def bodies_and_shapes(self):
+        if self.body is None:
+            return []
         bs = [self.body] + self.shapes
         try:
             for c in self.components:
@@ -94,11 +116,13 @@ class Component(object):
             icon.scale = float(size) / s
         return icon
 
-    @property
-    def position(self):
+    def get_position(self):
         """World position of the component."""
         p = self.attachment_point + self.insertion_point.rotated(math.degrees(self.angle))  # position of the insertion point in body space
         return v(self.squid.body.local_to_world(p))
+    position = property(get_position)
+
+    home_position = get_position
     
     @property
     def rotation(self):
@@ -179,6 +203,11 @@ class Component(object):
 
     apply_force = apply_force_relative
 
+    def apply_torque(self, t):
+        """Apply torque t
+        """
+        self.squid.body.torque += t 
+
     def reset(self):
         """Reset the state of the component."""
 
@@ -197,6 +226,12 @@ class ActivateableComponent(Component):
     def is_active(self):
         return self.active
 
+    def on_start(self):
+        pass
+
+    def on_stop(self):
+        pass
+
     def reset(self):
         """Reset the state of the component."""
         self.active = self.initial
