@@ -72,8 +72,7 @@ class Slots(object):
         self.slots[id].component = component
         self.components.append(component)
         self.components.sort(key=lambda c: bool(c.slot_mask & Slot.SIDE))
-        component.slot = self.slots[id]
-        component.attachment_point = self.slots[id].pos
+        component.attach_at_slot(self.slots[id])
 
     def attach_new(self, id, component_class):
         """Attach a new instance of component_class at id"""
@@ -118,6 +117,7 @@ class Susie(Component):
         img = loader.image('data/sprites/squid-shadow.png') 
         w = img.width
         img.anchor_x = w * 0.5
+        img.anchor_y = img.height * 0.5
         cls.shadow_image = img
 
     def __init__(self, world):
@@ -128,12 +128,12 @@ class Susie(Component):
         self.slots = Slots(self)
         self.slots.add_slot(self.circles[2][0], Slot.SIDE)
         self.slots.add_slot(self.circles[3][0], Slot.SIDE)
-        self.slots.add_slot(self.circles[2][0] + v(0, 20), Slot.TOP)
+        self.slots.add_slot(self.circles[2][0] + v(0, 22), Slot.TOP)
         self.slots.add_slot(self.circles[2][0] - v(0, 20), Slot.BOTTOM)
-        self.slots.add_slot(self.circles[2][0] + v(85, 0), Slot.NOSE)
+        self.slots.add_slot(self.circles[2][0] + v(82, 3), Slot.NOSE)
         self.slots.add_slot(self.circles[3][0] + v(0, 15), Slot.TOP)
-        self.slots.add_slot(self.circles[3][0] - v(0, 15), Slot.BOTTOM)
-        self.slots.add_slot(self.circles[3][0] - v(38, 4), Slot.NOSE)
+        self.slots.add_slot(self.circles[3][0] - v(0, 16), Slot.BOTTOM)
+        self.slots.add_slot(self.circles[3][0] - v(34, 1), Slot.TAIL)
 
         self.spikes = []
         self.reset()
@@ -142,6 +142,8 @@ class Susie(Component):
         bs = [self.body] + self.shapes
         for s in self.spikes:
             bs.extend(s.bodies_and_shapes())
+        for c in self.slots.components:
+            bs.extend(c.bodies_and_shapes())
         return bs
     
     def create_body(self):
@@ -150,12 +152,12 @@ class Susie(Component):
 #            TentacleSpike(self, v(-90, 0)),
         ]
 
-    def reset(self):
+    def reset(self, position=(250, 80)):
         self.create_body()
         self.body.angular_velocity_limit = 1.5  # Ensure Susie can't spin too fast
         self.body.mass = self.total_weight()
         self.fuel = self.fuel_capacity()
-        self.position = (250, 80)
+        self.position = position
         for a in self.slots.components:
             a.reset()
 
@@ -181,9 +183,14 @@ class Susie(Component):
         return self.fuel > 0
 
     def set_position(self, pos):
-        trans = pos - self.body.position
         self.body.position = pos
         self.sprite.position = pos
+        for c in self.slots.components:
+            try:
+                c.position = Component.get_position(c)
+            except AttributeError:
+                # position isn't settable, probably because it's derived
+                pass
 #        self.spikes[0].position += trans
 
     def get_position(self):
@@ -205,6 +212,9 @@ class Susie(Component):
     def fuel_capacity(self):
         return sum([c.CAPACITY for c in self.slots.components], self.CAPACITY)
 
+    def need_fuel(self):
+        return any([getattr(c, 'FUEL_CONSUMPTION', 0) for c in self.slots.components])
+
     def attach(self, component_class, pos=None):
         if pos is None:
             pos = self.slots.find_slot(component_class)
@@ -233,7 +243,7 @@ class Susie(Component):
 
     def draw_shadow(self):
         if self.body.position.y > SEA_LEVEL:
-            self.shadow.set_position(self.body.position.x, SEA_LEVEL)
+            self.shadow.set_position(self.body.position.x, SEA_LEVEL + 23)
             self.shadow.opacity = max(255 - self.body.position.y, 0)
             self.shadow.draw()
 
